tendril.frontend.parts package
==============================

Submodules
----------

.. toctree::

   tendril.frontend.parts.forms
   tendril.frontend.parts.tasks

Module contents
---------------

.. automodule:: tendril.frontend.parts
    :members:
    :undoc-members:
    :show-inheritance:
